==> haskell-lucid-2.9.10-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-CqVtVP3rZ113Wfkgp4s9Dr
key: lucid-2.9.10-CqVtVP3rZ113Wfkgp4s9Dr
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: 29c9833a1d1b395d049258b19415cb24
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-CqVtVP3rZ113Wfkgp4s9Dr
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt mtl-2.2.2 text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lucid-2.9.10-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-lucid.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lucid
version: 2.9.10
id: lucid-2.9.10-9qRh3ADlw7aBRpYuKx4uVY
key: lucid-2.9.10-9qRh3ADlw7aBRpYuKx4uVY
license: BSD-3-Clause
copyright: 2014-2017 Chris Done
maintainer: chrisdone@gmail.com, oleg.grenrus@iki.fi
author: Chris Done
homepage: https://github.com/chrisdone/lucid
synopsis: Clear to write, read and edit DSL for HTML
description:
    Clear to write, read and edit DSL for HTML.
    .
    * Names are consistent, and do not conflict with base or are keywords (all have suffix @_@)
    .
    * Same combinator can be used for attributes and elements (e.g. '\''style_'\'')
    .
    * For more, read <https://chrisdone.com/posts/lucid the blog post>
    .
    See the "Lucid" module for more documentation.
category: Web
abi: 654119bd00cdf34398b698130b60c9d2
exposed: True
exposed-modules:
    Lucid Lucid.Base Lucid.Bootstrap Lucid.Html5
import-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
library-dirs: /usr/lib/ghc-8.4.3/site-local/lucid-2.9.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/lucid-2.9.10
hs-libraries: HSlucid-2.9.10-9qRh3ADlw7aBRpYuKx4uVY
depends:
    base-4.11.1.0 blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028
    bytestring-0.10.8.2 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt mtl-2.2.2 text-1.2.3.0
    transformers-0.5.5.0
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=84ea2e9d87e56b4ceb814f92752c9208
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-lucid/html/lucid.haddock
haddock-html: /usr/share/doc/haskell-lucid/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
